# -*- coding: utf-8 -*-
"""
Example views.
    -Don't use these in production.
    -URL schemas and slugified routes not yet implemented.
    -Refactor as class based views.
"""
from django.shortcuts import render_to_response, RequestContext
from .models import Sitemap


def get_navigation_tree(request, group=None):
    if group == None:
        nodes = Sitemap.objects.all()
    else:
        nodes = Sitemap.objects.filter(groups=group)
    templatePath = "dj_contentmodel/sitemap.html"
    return render_to_response(templatePath, {'nodes': nodes}, context_instance=RequestContext(request))


def get_content_tree(request, group=None):
    if group == None:
        nodes = Sitemap.objects.all()
    else:
        nodes = Sitemap.objects.filter(groups=group)
    templatePath = "dj_contentmodel/taxonomy.html"
    return render_to_response(templatePath, {'nodes': nodes}, context_instance=RequestContext(request))



# -*- coding: utf-8 -*-
"""
Example navigation.
    -Don't use these in production.
    -URL schemas and slugified routes not yet implemented.
"""
from django.conf.urls import url
import views


urlpatterns = [
    url(r'^navigation/(?P<group>[0-9]+)?$', views.get_navigation_tree),
    url(r'^sitemap/(?P<group>[0-9]+)?$', views.get_content_tree),
]




# -*- coding: utf-8 -*-
"""
Abstract classes for creating taxonomies.
-Group is the only concrete class
"""
from __future__ import unicode_literals

from django.db import models
from mptt.models import MPTTModel, TreeForeignKey, TreeManyToManyField
from taggit.managers import TaggableManager


class Group(MPTTModel):
    """Authentication and authorization has not been implemented.
        -This is feigned through querying groups for now.
        -Template queries for all taxa assigned to a group.
    """
    name = models.CharField(max_length=50)
    parent = TreeForeignKey('self', null=True, blank=True, related_name='children', db_index=True)

    class MPTTMeta:
        order_insertion_by = ['name']

    def __unicode__(self):
        return self.name


class Taxonomy(MPTTModel):
    """Inherit from Taxonomy to create taxa."""
    groups = TreeManyToManyField('Group')
    parent = TreeForeignKey('self', null=True, blank=True, related_name='children', db_index=True)
    collections = models.ManyToManyField('Collection', blank=True)
    name = models.CharField(max_length=255)
    tags = TaggableManager(blank=True)

    class Meta:
        abstract = True
        verbose_name_plural = "Taxa"

    class MPTTMeta:
        order_insertion_by = ['name']

    def __unicode__(self):
        return self.name


class Collection(models.Model):
    """Assign content to collections and collections to taxa.
        -content in multiple containers assigned to taxa will display duplicates.
    """
    name = models.CharField(max_length=100)
    tags = TaggableManager(blank=True)

    class Meta:
        abstract = True
        ordering = ['name']

    def __unicode__(self):
        return self.name


class Content(models.Model):
    name = models.CharField(max_length=255)
    tags = TaggableManager(blank=True)

    class Meta:
        abstract = True
        ordering = ['name']

    def __unicode__(self):
        return self.name


class Attachment(models.Model):
    recipients = models.ManyToManyField('Content', blank=True)
    name = models.CharField(max_length=255)
    tags = TaggableManager(blank=True)

    class Meta:
        abstract = True
        ordering = ['name']

    def __unicode__(self):
        return self.name
